@@ -30,7 +30,7 @@ impl Dumper for Sqlite {
                     name_row.push(
                         statement
                             .read::<String>(1)
-                            .expect("Read name column from sqlite error"),
+                            .expect("Read sqlite column error"),
                     );
                 }
                 Ok(sqlite::State::Done) => break,
